#pragma comment(linker, "/STACK:1000000000")
#define _CRT_SECURE_NO_WARNINGS
#include <iostream>
#include <cstdio>
#include <vector>
#include <ctime>
#include <map>
#include <climits>
#include <bitset>
#include <set>
#include <string>
#include <cstdlib>
#include <cassert>
#include <cmath>
#include <algorithm>
using namespace std;

typedef long long ll;
typedef double dbl;

#define sz(x) (int)x.size()
#define pb push_back
#define all(x) x.begin(),x.end()
#define X first
#define Y second
#define mp make_pair

const long double eps = 1e-11;

bool eq(long double a, long double b) {
	return fabs(a - b) < eps;
}

bool ls(long double a, long double b) {
	return a < b && !eq(a, b);
}

struct point {
	long double x, y, z;
	long double m;
	point() {}
	point(long double x, long double y, long double z, long double m) : x(x), y(y), z(z), m(m) {}
};

point operator+ (point a, point b) {
	return{ a.x + b.x, a.y + b.y, a.z + b.z, a.m + b.m };
}

point operator* (long double k, point a) {
	return{ k * a.x, k * a.y, k * a.z, a.m };
}

point get_mc(point a, point b) {
	return (1.0 / (a.m + b.m)) * (a.m * a + b.m * b);
}

void solveJ() {
	int n, w, h, m;
	scanf("%d%d%d%d", &n, &w, &h, &m);
	w = 1.0;

	vector < point > suf_mc(h);
	vector < bitset <10000> > exists(h);
	vector <int> left(h), right(h);

	for (int i = 0; i < h; i++) {
		suf_mc[i] = { 0.5 * w * n, 0.5 * w * n, 0.5 * (i + h), 1.0 * (h - i) * w * n };
		for (int j = 0; j < n; j++)
			exists[i][j] = 1;
		left[i] = 0;
		right[i] = n - 1;
	}

	for (int _ = 0; _ < m; _++) {
		int l, k;
		scanf("%d%d", &l, &k);
		l--; k--;

		exists[l][k] = 0;
		while (left[l] < n && exists[l][left[l]] == 0)
			left[l]++;
		while (right[l] >= 0 && exists[l][right[l]] == 0)
			right[l]--;

		point cur_mc;
		if (l % 2 == 0)
			cur_mc = { (0.5 + k) * w, 0.5 * w * n, 0.5 + l, -1.0 * w };
		else
			cur_mc = { 0.5 * w * n, (0.5 + k) * w, 0.5 + l, -1.0 * w };

		for (int i = l; i >= 0; i--)
			suf_mc[i] = get_mc(suf_mc[i], cur_mc);
		
		for (int i = 0; i < h - 1; i++) {
			point head_mc = suf_mc[i + 1];
			long double lx, rx, ly, ry;
			if (i % 2 == 0) {
				ly = 0, ry = w * n;
				lx = w * left[i], rx = (right[i] + 1) * w;
			}
			else {
				lx = 0, rx = w * n;
				ly = w * left[i], ry = (right[i] + 1) * w;
			}

			if (!(ls(lx, head_mc.x) && ls(head_mc.x, rx) &&
				ls(ly, head_mc.y) && ls(head_mc.y, ry))) {
				puts("yes");
				printf("%d\n", _ + 1);
				return;
			}
		}
	}
	puts("no");
}

#define TASK "jenga"
int main() {
#ifdef NSU
	freopen("input.txt", "r", stdin);
	freopen("output.txt", "w", stdout);
#else
	freopen(TASK".in", "r", stdin);
	freopen(TASK".out", "w", stdout);
#endif

	solveJ();

#ifdef NSU
	cerr << "Time: " << (double)clock() / CLOCKS_PER_SEC << endl;
#endif
	return 0;
}
