import java.io.*;
import java.util.ArrayList;
import java.util.StringTokenizer;

import static java.util.Collections.sort;

public class Main {

    public static void main(String[] args) throws IOException {
        new Main().run();
    }

    BufferedReader in;
    PrintWriter out;
    StringTokenizer st = new StringTokenizer("");

    final String fileIn = "hard.in";
    final String fileOut = "hard.out";

    private void run() throws IOException {
        in = new BufferedReader(new FileReader(new File(fileIn)));
        out = new PrintWriter(fileOut);

//        in = new BufferedReader(new InputStreamReader(System.in));
//        out = new PrintWriter(System.out, true);

        solve();

        in.close();
        out.close();
    }

    int MAX_X = 32767;
    int MIN_X = -32768;

    class P implements Comparable<P> {
        boolean open;
        int x;

        public P(boolean open, int x) {
            this.open = open;
            this.x = x;
        }

        int getValue() {
            return open ? x : x+1;
        }

        @Override
        public int compareTo(P o) {
            int comp = Integer.compare(getValue(), o.getValue());
            if (comp == 0) {
                if (open != o.open) {
                    comp = open ? -1 : 1;
                }
            }
            return comp;
        }
    }

    class S {
        int l, r;

        public S(int l, int r) {
            this.l = l;
            this.r = r;
        }
    }

    private void solve() throws IOException {
        int linesCnt = 0;

        ArrayList<P> que = new ArrayList<>();

        boolean failed = false;

        while (true) {
            String line = in.readLine();
            if (line == null) return;

            String[] items = line.split(" ");

            int l, r;

            boolean isLR = items.length > 6;

            if (isLR) {
                l = Integer.parseInt(items[2]);
                r = Integer.parseInt(items[6]);
            } else {
                if (items[1].equals("<=")) {
                    l = MIN_X;
                    r = Integer.parseInt(items[2]);
                } else {
                    l = Integer.parseInt(items[2]);
                    r = MAX_X;
                }
            }

            if (l > r) {
                failed = true;
            }

            que.add(new P(true, l));
            que.add(new P(false, r));

            if (!items[items.length - 1].equals("||")) break;
        }

        if (failed) {
            out.println("false");
            return;
        }

        sort(que);

        int opened = 0;

        ArrayList<S> segments = new ArrayList<>();

        int currentOpened = 0;

        for (int i = 0; i < que.size(); ++i) {
            P point = que.get(i);
            if (point.open) {
                opened++;

                if (opened == 1) {
                    currentOpened = point.x;
                }
            } else {
                opened--;
                if (opened == 0) {
                    segments.add(new S(currentOpened, point.x));
                }
            }
        }

        if (segments.size() == 1) {
            S s = segments.get(0);
            if (s.l == MIN_X && s.r == MAX_X) {
                out.println("true");
                return;
            }
        }

        for (int i = 0; i < segments.size(); ++i) {
            S segment = segments.get(i);
            if (segment.l == MIN_X) {
                out.print(String.format("x <= %d", segment.r));
            } else if (segment.r == MAX_X) {
                out.print(String.format("x >= %d", segment.l));
            } else {
                out.print(String.format("x >= %d && x <= %d", segment.l, segment.r));
            }

            if (i != segments.size() - 1) {
                out.println(" ||");
            }
        }
    }

    int nextInt() throws IOException {
        return Integer.parseInt(nextToken());
    }

    double nextDouble() throws IOException {
        return Double.parseDouble(nextToken());
    }

    long nextLong() throws IOException {
        return Long.parseLong(nextToken());
    }

    String nextToken() throws IOException {
        while (!st.hasMoreTokens()) {
            st = new StringTokenizer(in.readLine());
        }
        return st.nextToken();
    }

    boolean EOF() throws IOException{
        while (st.hasMoreTokens()) {
            String line = in.readLine();
            if (line == null) return true;
            st = new StringTokenizer(line);
        }
        return false;
    }

}