import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;

public class Main {
    private static final int MIN = -32768;
    private static final int MAX = 32767;
    private static Scanner sc;
    private static FileWriter out;

    public static void main(String[] args) throws IOException {
        sc = new Scanner(new File("hard.in"));
        out = new FileWriter("hard.out");
        List<Condition> conditions = new ArrayList<>();
        while (true) {
            String next = sc.nextLine();
            conditions.add(Condition.fromString(next));
            if (!next.endsWith("||"))
                break;
        }

        List<Condition> resConditions = new ArrayList<>();
        for (Condition condition : conditions) {
            if (condition.isTrue()) {
                out.write("true");
                out.close();
                return;
            } else if (!condition.isFalse()) {
                addNewCondition(condition, resConditions);
            }
        }

        printConditions(resConditions);
        out.close();
        sc.close();
    }

    private static void addNewCondition(Condition condition, List<Condition> resConditions) {
        int leftIndex = findIndex(condition.min, resConditions);
        int rightIndex = findIndex(condition.max, resConditions);

        if (leftIndex == -1) {
            if (rightIndex == -1)
                resConditions.add(0, condition);
            else {
                if (condition.max < resConditions.get(rightIndex).max) {
                    condition.max = resConditions.get(rightIndex).max;
                    List<Condition> news = new ArrayList<>();
                    news.add(condition);
                    for (int i=rightIndex+1; i < resConditions.size(); i++)
                        news.add(resConditions.get(i));
                    resConditions.clear();
                    resConditions.addAll(news);
                }
            }
        } else {
            boolean aggrleft = false;
            boolean aggrright = false;
            if ((condition.min <= resConditions.get(leftIndex).max + 1)) {
                condition.min = resConditions.get(leftIndex).min;
                aggrleft = true;
            }
            if (condition.max <= resConditions.get(rightIndex).max) {
                condition.max = resConditions.get(rightIndex).max;
            }
            List<Condition> news = new ArrayList<>();
            for (int i =0; i < leftIndex; i++)
                news.add(resConditions.get(i));
            if (!aggrleft)
                news.add(resConditions.get(leftIndex));
            news.add(condition);
            for (int i=rightIndex+1; i < resConditions.size(); i++)
                news.add(resConditions.get(i));
            resConditions.clear();
            resConditions.addAll(news);
        }


    }

    private static int findIndex(int max, List<Condition> resConditions) {
        for (int i=0; i < resConditions.size(); i++){
            if (max < resConditions.get(i).min)
                return i-1;
        }
        return resConditions.size()-1;
    }

    private static void printConditions(List<Condition> resConditions) throws IOException {
        if (resConditions.size() == 0)
            out.write("false");
        for (Condition resCondition : resConditions) {
            if (resCondition.isTrue()){
                out.write("true");
                return;
            }
        }

        StringBuilder res = new StringBuilder();
        for (int i=0; i<resConditions.size(); i++) {
            Condition c = resConditions.get(i);
            if (c.min != MIN && c.max != MAX) {
                res.append("x >= ").append(c.min)
                    .append(" && x <= ").append(c.max);
            } else if (c.min != MIN) {
                res.append("x >= ").append(c.min);
            } else if (c.max != MAX) {
                res.append("x <= ").append(c.max);
            }
            if (i != resConditions.size() - 1)
                res.append(" ||\n");
        }
        out.write(res.toString());
    }


    private static class Condition {
        int min, max;

        Condition(int moreThan, int lessThan) {
            this.min = moreThan;
            this.max = lessThan;
        }


        static Condition fromString(String exp) {
            String[] split = exp.split(" ");
            int min = MIN, max = MAX;
            if (split[1].equals(">="))
                min = Integer.parseInt(split[2]);
            else
                max = Integer.parseInt(split[2]);

            if (split.length > 4) {
                if (split[5].equals(">="))
                    min = Integer.parseInt(split[6]);
                else
                    max = Integer.parseInt(split[6]);
            }

            return new Condition(min, max);
        }

        boolean isTrue() {
            return min == max || min == MIN && max == MAX;
        }

        boolean isFalse() {
            return min > max;
        }
    }
}
