import java.io.*;
import java.util.*;

public class TaskE {

    BufferedReader reader;
    StringTokenizer tok;
    PrintWriter out;

    String nextToken() throws IOException {
        if (tok == null || !tok.hasMoreElements()) {
            String line = reader.readLine();
            if (line == null) {
                return null;
            }
            tok = new StringTokenizer(line);
        }
        return tok.nextToken();
    }

    Integer nextInt() throws IOException {
        return Integer.parseInt(nextToken());
    }

    Long nextLong() throws IOException {
        return Long.parseLong(nextToken());
    }

    Double nextDouble() throws IOException {
        return Double.parseDouble(nextToken());
    }

    public static void main(String[] args) throws IOException {
        TaskE taskE = new TaskE();
        taskE.open();
        taskE.solve();
        taskE.close();
    }

    static class Pair implements Comparable<Pair> {
        int index;
        long bValue;

        public Pair(int index, long bValue) {
            this.index = index;
            this.bValue = bValue;
        }

        @Override
        public int compareTo(Pair o) {
            return Long.compare(this.bValue, o.bValue);
        }
    }

    private void close() {
        out.flush();
    }

    long[] tree;
    long[] treeAdd;
    long[] treeTime;
    long[] treeTimeAdd;

//    void build(long[] a, int v, int tl, int tr) {
//        if (tl == tr) {
//            tree[v] = a[v];
//        } else {
//            int tm = (tl + tr) / 2;
//            build(a, v * 2, tl, tm);
//            build(a, v * 2 + 1, tm + 1, tr);
//            tree[v] = tree[v * 2] + tree[v * 2 + 1];
//        }
//    }

    void add(int v, int tl, int tr, int l, int r, long adding, long[] tree, long[] treeAdd) {
        if (l > r) {
            return;
        } else if (tl == l && tr == r) {
            tree[v] += adding * (tr - tl + 1);
            treeAdd[v] += adding;
        } else {
            int tm = (tl + tr) / 2;
            push(v, tl, tm, tr, tree, treeAdd);
            add(v * 2, tl, tm, l, Math.min(tm, r), adding, tree, treeAdd);
            add(v * 2 + 1, tm + 1, tr, Math.max(l, tm + 1), r, adding, tree, treeAdd);
        }
    }

    long sum(int v, int tl, int tr, int l, int r, long[] tree, long[] treeAdd) {
        if (l > r) {
            return 0;
        } else if (tl == l && tr == r) {
            return tree[v];
        } else {
            int tm = (tl + tr) / 2;
            push(v, tl, tm, tr, tree, treeAdd);
            return sum(v * 2, tl, tm, l, Math.min(tm, r), tree, treeAdd) + sum(v * 2 + 1, tm + 1, tr, Math.max(l, tm + 1), r, tree, treeAdd);
        }
    }

    void push(int v, int tl, int tm, int tr, long[] tree, long[] treeAdd) {
        if (treeAdd[v] == 0) {
            return;
        }
        tree[v * 2] += treeAdd[v] * (tm - tl + 1);
        treeAdd[v * 2] += treeAdd[v];
        tree[v * 2 + 1] += treeAdd[v] * (tr - tm);
        treeAdd[v * 2 + 1] += treeAdd[v];
        treeAdd[v] = 0;
    }

    int getIndex(Pair[] arr, long edge) {
        if (arr[0].bValue >= edge) {
            return -1;
        }
        int low = 0;
        int high = arr.length - 1;
        while (low < high - 1) {
            int center = (low + high) / 2;
            if (arr[center].bValue < edge) {
                low = center;
            } else {
                high = center - 1;
            }
        }
        if (low != high) {
            if (arr[high].bValue < edge) {
                low = high;
            }
        }
        return low;
    }

    private void solve() throws IOException {
        int n = nextInt();
        int q = nextInt();
        long[] req = new long[n];
        long[] t = new long[n];
        for (int i = 0; i < n; i++) {
            String symbol = nextToken();
            t[i] = nextInt();
            req[i] = nextInt();
            if ("+".equals(symbol)) {
                req[i] = -req[i];
            }
        }
//        long[] b = new long[q];
        Pair[] bPairs = new Pair[q];
        for (int i = 0; i < q; i++) {
            long bValue = nextInt();
            bPairs[i] = new Pair(i, bValue);
        }
        Arrays.sort(bPairs);
        long[] prefReq = new long[n];
        for (int i = 0; i < n; i++) {
            prefReq[i] = req[i];
            if (i > 0) {
                prefReq[i] += prefReq[i - 1];
            }
        }
        long wholeSum = 0;
        for (int i = 0; i < n - 1; i++) {
            wholeSum += prefReq[i] * (t[i + 1] - t[i]);
        }
        tree = new long[q * 4];
        treeAdd = new long[q * 4];
        treeTime = new long[q * 4];
        treeTimeAdd = new long[q * 4];
        for (int i = 0; i < n - 1; i++) {
            int edgeIndex = getIndex(bPairs, prefReq[i]);
            if (edgeIndex != -1) {
                add(1, 0, q - 1, 0, edgeIndex, t[i + 1] - t[i], treeTime, treeTimeAdd);
//                add(1, 0, q - 1, 0, edgeIndex, prefReq[i] * t[i], tree, treeAdd);
            }
            if (edgeIndex != q - 1) {
                add(1, 0, q - 1, edgeIndex + 1, q - 1, prefReq[i] * (t[i + 1] - t[i]), tree, treeAdd);
//                add(1, 0, q - 1, edgeIndex + 1, q - 1, t[i], treeTime, treeTimeAdd);
            }
        }
        long[] res = new long[q];
        for (int i = 0; i < q; i++) {
            if (bPairs[i].bValue < prefReq[n - 1]) {
                res[bPairs[i].index] = -1;
                continue;
            }
            long currRes = wholeSum;
            currRes -= sum(1, 0, q - 1, i, i, tree, treeAdd);
            currRes -= sum(1, 0, q - 1, i, i, treeTime, treeTimeAdd) * bPairs[i].bValue;
            res[bPairs[i].index] = currRes;
        }
        for (int i = 0; i < q; i++) {
            if (res[i] == -1) {
                out.println("INFINITY");
            } else {
                out.println(res[i]);
            }
        }
    }

    private void open() throws FileNotFoundException {
        reader = new BufferedReader(new InputStreamReader(new FileInputStream("expect.in")));
        out = new PrintWriter("expect.out");
    }

}
