import java.io.*;
import java.util.ArrayList;
import java.util.StringTokenizer;

public class TaskJ {

    private static final double EPS = +(1e-13);
    BufferedReader reader;
    StringTokenizer tok;
    PrintWriter out;

    String nextToken() throws IOException {
        if (tok == null || !tok.hasMoreElements()) {
            String line = reader.readLine();
            if (line == null) {
                return null;
            }
            tok = new StringTokenizer(line);
        }
        return tok.nextToken();
    }

    Integer nextInt() throws IOException {
        return Integer.parseInt(nextToken());
    }

    Long nextLong() throws IOException {
        return Long.parseLong(nextToken());
    }

    Double nextDouble() throws IOException {
        return Double.parseDouble(nextToken());
    }

    public static void main(String[] args) throws IOException {
        TaskJ main = new TaskJ();
        main.open();
        main.solve();
        main.close();
    }

    private void open() throws FileNotFoundException {
        reader = new BufferedReader(new InputStreamReader(new FileInputStream("jenga.in")));
        out = new PrintWriter("jenga.out");
    }

    private void close() {
        out.flush();
    }

    class ListNode {
        ListNode prev = null, next = null;

        ListNode removeAndRetPrev() {
            if (this.next != null) this.next.prev = this.prev;
            if (this.prev != null) this.prev.next = this.next;
            return this.prev;
        }
    }

    class Pair {
        int first, second;

        public Pair(int first, int second) {
            this.first = first;
            this.second = second;
        }
    }

    ArrayList<Pair>[] tower;
    Center[] centers;

    int n;
    int h;
    int w;

    private void solve() throws IOException {
        n = nextInt();
        //TODO use w
        w = nextInt();
        h = nextInt();
        int m = nextInt();
        if (n == 1) {
            check1(m, h);
            return;
        }
        tower = new ArrayList[h];
        centers = new Center[h];
        for (int i = 0; i < h; i++) {
            tower[i] = new ArrayList<Pair>();
            centers[i] = new Center(n * w / 2.0, n * w / 2.0, n * w);
            ArrayList<Pair> towerLayer = tower[i];
            towerLayer.add(new Pair(0, n - 1));
        }
        for (int i = 0; i < m; i++) {
            int l = nextInt() - 1, k = nextInt() - 1;
            delete(l, k);
            if (!checkTower()) {
                out.println("yes");
                out.println(i + 1);
                return;
            }
        }
        out.println("no");
    }

    class Center {
        double[] coord = new double[2];
        int m;

        public Center(double x, double y, int m) {
            this.coord[0] = x;
            this.coord[1] = y;
            this.m = m;
        }

        public Center(Center other) {
            this.coord[0] = other.coord[0];
            this.coord[1] = other.coord[1];
            this.m = other.m;
        }

        public Center(int level, double x, double y, int m) {
            int ind = level % 2; //TODO
            this.coord[ind] = x;
            this.coord[ind ^ 1] = y;
            this.m = m;
        }

        public void update(Center other) {
            if (other.m == 0) return;
            double diffCoord[] = new double[2];
            for (int i = 0; i < 2; i++) {
                diffCoord[i] = other.coord[i] - coord[i];
            }
//            double sqrtL = Math.sqrt()
            double koeff = (other.m) / (this.m + other.m + 0.0);
            for (int i = 0; i < 2; i++) {
                this.coord[i] += koeff * diffCoord[i];
            }
            this.m += other.m;
        }
    }

    private boolean checkTower() {
        Center sum = new Center(centers[h - 1]);
        int curLevel = h - 2;
        boolean hasTop = tower[h - 1].size() > 0;
        while (curLevel >= 0) {
            double coord = sum.coord[curLevel % 2]; //TODO
            boolean found = false;

            ArrayList<Pair> spaceLvl = tower[curLevel];
            if (spaceLvl.size() == 0) {
                if (hasTop) return false;
                curLevel--;
                continue;
            } else hasTop = true;

            int first = spaceLvl.get(0).first;
            int last = spaceLvl.get(spaceLvl.size() - 1).second + 1;

            if (coord + EPS >= last * w || coord - EPS <= first*w) return false; //TODO double

            sum.update(centers[curLevel]);

            curLevel--;
        }
        return true;
    }

    private void delete(int lvl, int k) {
        ArrayList<Pair> layer = tower[lvl];
        for (int i = 0; i < layer.size(); i++) {
            Pair pair = layer.get(i);
            if (pair.first <= k && pair.second >= k) {
                if (pair.first == k && pair.second == k) {
                    layer.remove(i);
                } else if (pair.first == k) {
                    pair.first = k + 1;
                } else if (pair.second == k) {
                    pair.second = k - 1;
                } else {
                    Pair pairNew = new Pair(k + 1, pair.second);
                    pair.second = k - 1;
                    layer.add(i + 1, pairNew);
                }
            }
        }
        centers[lvl].update(new Center(lvl, n * w / 2.0, k + 0.5 * w, -1));
    }

    private void check1(int m, int h) throws IOException {
        for (int i = 0; i < m; i++) {
            int l = nextInt() - 1, k = nextInt() - 1;
            if (l < h) {
                out.println("yes");
                out.println(i + 1);
                return;
            }
            h--;
        }
        out.println("no");
    }
}
