#include <algorithm>
#include <cstdio>
#include <map>
#include <vector>
using namespace std;

typedef long long ll;

struct Diff {
	ll t, k;
};

struct Event {
	enum EventType { DOWN, UP };

	ll t;
	EventType type;
};

ll remove(map< ll, ll > &segments, ll l, ll r) {
	auto it = segments.upper_bound(l);
	vector< ll > to_remove;
	vector< pair< ll, ll > > to_add;
	if (it != segments.begin()) {
		it--;

		if (it->second > l) {
			to_remove.push_back(it->first);
			if (it->first < l)
				to_add.emplace_back(it->first, l);
			if (r < it->second)
				to_add.emplace_back(r, it->second);
		}
	}
	it++;
	while (it != segments.end() && r > it->first) {
		to_remove.push_back(it->first);
		if (r < it->second)
			to_add.emplace_back(r, it->second);

		it++;
	}

	ll removed_area = 0;
	for (ll l : to_remove) {
		removed_area += segments[l] - l;
		segments.erase(l);
	}
	for (const auto &item : to_add) {
		removed_area -= item.second - item.first;
		segments.insert(item);
	}
	return removed_area;
}

const ll T_INF = 2e9;

#define FILENAME "expect"

int main() {
	freopen(FILENAME ".in", "r", stdin);
	freopen(FILENAME ".out", "w", stdout);

	int n, q;
	scanf("%d%d\n", &n, &q);
	vector< Diff > diffs;
	ll value = 0;
	ll max_h = 0;
	for (int i = 0; i < n; i++) {
		char oper;
		ll t, k;
		scanf("%c %lld %lld\n", &oper, &t, &k);
		if (oper == '+')
			k = -k;

		diffs.push_back(Diff{t, k});
		value += k;

		max_h = max(max_h, value);
	}
	ll h_start = max(0LL, value);

	value = 0;
	map< ll, ll > segments; // segments[l] = r
	ll open_t = -1;
	ll cur_area = 0;
	map< ll, vector< Event > > events;
	map< ll, ll > row_area; // row_area[h] = total_area
	for (unsigned i = 0; i < diffs.size(); i++) {
		ll new_value = value + diffs[i].k;
		if (value <= h_start && new_value > h_start)
			open_t = diffs[i].t;
		else
		if (value > h_start && new_value <= h_start) {
			segments[open_t] = diffs[i].t;
			cur_area = diffs[i].t - open_t;
		}

		if (diffs[i].k > 0)
			events[value].push_back(Event{diffs[i].t, Event::DOWN});
		else
			events[new_value].push_back(Event{diffs[i].t, Event::UP});

		value = new_value;
	}
	row_area[h_start] = cur_area;

	/*for (auto it = events.begin(); it != events.end(); it++) {
		printf("dbg: events[%lld]:\n", it->first);
		for (const auto &item : it->second)
			printf("(%d, %s) ", item.t, item.type == Event::DOWN ? "down" : "up");
		printf("\n");
	}*/

	auto h_start_it = events.find(h_start);
	h_start_it++;
	for (auto it = h_start_it; it != events.end(); it++) {
		if (it->second[0].type == Event::DOWN)
			it->second.insert(it->second.begin(), Event{-T_INF, Event::UP});
		if (it->second.rbegin()->type == Event::UP)
			it->second.push_back(Event{T_INF, Event::DOWN});

		const Event *last_up = nullptr;
		for (const auto &ev : it->second) {
			if (ev.type == Event::UP)
				last_up = &ev;
			else {
				ll removed_area = remove(segments, last_up->t, ev.t);
				//printf("dbg: removed_area from [%lld, %lld) = %lld", last_up->t, ev.t, removed_area);
				cur_area -= removed_area;
			}
		}

		row_area[it->first] = cur_area;
	}

	/*for (auto it = row_area.begin(); it != row_area.end(); it++) {
		printf("dbg: row_area[%lld] = %lld\n", it->first, it->second);
	}*/

	row_area[max_h] = 0;
	ll prev_h = row_area.rbegin()->first;
	map< ll, ll > total_area;
	map< ll, ll > prev_heights;
	ll sum = 0;
	for (auto it = row_area.rbegin(); it != row_area.rend(); it++) {
		sum += it->second * (prev_h - it->first);
		total_area[it->first] = sum;

		prev_heights[it->first] = prev_h;
		prev_h = it->first;
	}

	for (int i = 0; i < q; i++) {
		ll b;
		scanf("%lld", &b);

		if (b >= max_h) {
			printf("0\n");
			continue;
		}
		auto it = total_area.upper_bound(b);
		if (it == total_area.begin()) {
			printf("INFINITY\n");
			continue;
		}
		it--;
		printf("%lld\n", it->second - (row_area[it->first] * ((prev_heights[it->first] - it->first) - (prev_heights[it->first] - 1 - b) - 1)));
	}
	return 0;
}