#include <iostream>
#include <cstdio>
#include <cmath>
#include <algorithm>
#include <string>
#include <vector>
using namespace std;

typedef long long int int64;

const int OPEN = -1;
const int CLOSE = 1;

const int L = -32768;
const int R = 32767;


struct Event
{
	int x, type;
	Event() : x(), type() {}
	Event(int _x, int _type) : x(_x), type(_type) {}

	bool operator < (const Event & other) const
	{
		if (x != other.x)
			return x < other.x;
		return type < other.type;
	}
};

vector<Event> e_list;

void say_true()
{
	printf("true\n");
	exit(0);
}

void say_false()
{
	printf("false\n");
	exit(0);
}

vector<int> read_nums(string line)
{
	vector<int> res;

	int ptr = 0;
	while (ptr < (int)line.length())
	{
		if (line[ptr] == '-' || isdigit(line[ptr]))
		{
			int sign = 1;
			if (line[ptr] == '-')
			{
				sign = -1;
				ptr++;
			}

			int x = 0;
			while (ptr < (int)line.length() && isdigit(line[ptr]))
			{
				x = x * 10 + (line[ptr] - '0');
				ptr++;
			}

			res.push_back(x * sign);
		}
		else
			ptr++;
	}

	return res;
}

bool contains(string str, string a)
{
	for (int i = 0; i < (int)str.length(); i++)
		if (str.substr(i, (int)a.length()) == a)
			return true;
	return false;
}

void add_seg(int a, int b)
{
	e_list.push_back(Event(a, OPEN));
	e_list.push_back(Event(b + 1, CLOSE));
}

void read_segs()
{
	string line;
	while (getline(cin, line))
	{
		vector<int> list = read_nums(line);
		
		if (list.size() == 1)
		{
			int a = list[0];

			if (contains(line, ">="))
			{
				add_seg(a, R);
			}
			else
			{
				add_seg(L, a);
			}
		}
		else if (list.size() == 2)
		{
			int a = list[0];
			int b = list[1];

			if (a > b)
				say_false();

			add_seg(a, b);
		}
		else
			throw;
	}

	sort(e_list.begin(), e_list.end());
}

int main()
{
#ifdef LOCAL
	freopen("input.txt", "r", stdin);
#else
	freopen("hard.in", "r", stdin);
	freopen("hard.out", "w", stdout);
#endif

	read_segs();

	vector<pair<int, int> > un_list;

	int op_cnt = 0;
	int last_x;

	for (Event e : e_list)
	{
		if (e.type == OPEN)
		{
			if (op_cnt == 0)
				last_x = e.x;
			op_cnt++;
		}
		else if (e.type == CLOSE)
		{
			op_cnt--;
			if (op_cnt == 0)
				un_list.emplace_back(last_x, e.x - 1);
		}
	}
	
	if (un_list.empty())
		throw;

	if (un_list.size() == 1 && un_list[0].first == L && un_list[0].second == R)
		say_true();

	for (int i = 0; i < (int)un_list.size(); i++)
	{
		int a = un_list[i].first;
		int b = un_list[i].second;

		if (a == L)
			printf("x <= %d", b);
		else if (b == R)
			printf("x >= %d", a);
		else
			printf("x >= %d && x <= %d", a, b);

		if (i != (int)un_list.size() - 1)
			printf(" ||");
		printf("\n");
	}

	return 0;
}