import java.util.*;
import java.io.*;

public class K {

	BufferedReader br;
	StringTokenizer st;
	PrintWriter out;

	boolean areSame(Picture a, Picture b) {
		a = boundingBox(a);
		b = boundingBox(b);

		return Arrays.deepEquals(a.f, b.f);
	}

	static class Picture {
		int h, w;
		char[][] f;

		int dx, dy;

		public Picture(int h, int w, char[][] f, int dx, int dy) {
			this.h = h;
			this.w = w;
			this.f = f;
			this.dx = dx;
			this.dy = dy;
		}

	}

	Picture boundingBox(Picture p) {
		int minX = p.h;
		int maxX = -1;
		int minY = p.w;
		int maxY = -1;

		for (int i = 0; i < p.h; i++) {
			for (int j = 0; j < p.w; j++) {

				if (p.f[i][j] == '*') {

					minX = Math.min(minX, i);
					maxX = Math.max(maxX, i);

					minY = Math.min(minY, j);
					maxY = Math.max(maxY, j);
				}
			}
		}

		if (minX == p.h) {
			return new Picture(0, 0, new char[0][0], 0, 0);
		}

		char[][] ret = new char[maxX - minX + 1][maxY - minY + 1];
		for (int i = minX; i <= maxX; i++)
			for (int j = minY; j <= maxY; j++) {
				ret[i - minX][j - minY] = p.f[i][j];
			}

		return new Picture(maxX - minX + 1, maxY - minY + 1, ret, minX, minY);
	}

	Picture nextPicture() throws IOException {
		int h = nextInt();
		int w = nextInt();
		char[][] f = new char[h][];
		for (int i = 0; i < h; i++) {
			f[i] = nextToken().toCharArray();
		}

		return boundingBox(new Picture(h, w, f, 0, 0));
	}

	Picture rotate(Picture p) {
		char[][] ret = new char[p.w][p.h];

		for (int i = 0; i < p.h; i++) {
			for (int j = 0; j < p.w; j++) {

				int newJ = i;
				int newI = p.w - 1 - j;

				ret[newI][newJ] = p.f[i][j];

			}
		}

		return new Picture(p.w, p.h, ret, p.dx, p.dy);
	}

	int[] go2(Picture a, Picture b, Picture sum) {

		int lowA = a.w;
		int highA = -1;

		int lowSum = sum.w;
		int highSum = -1;

		for (int i = 0; i < a.w; i++) {

			if (a.f[0][i] == '*') {

				lowA = Math.min(lowA, i);
				highA = Math.max(highA, i);
			}
		}

		for (int i = 0; i < sum.w; i++) {

			if (sum.f[0][i] == '*') {
				lowSum = Math.min(lowSum, i);
				highSum = Math.max(highSum, i);
			}
		}

		if (lowA == a.w || lowSum == sum.w) {
			return null;
		}

		if (highA - lowA != highSum - lowSum) {
			return null;
		}

		int deltaX; // SUPER IMPORTANT

		if (lowA < lowSum) {

			deltaX = lowSum - lowA;

			a = insertColumns(a, deltaX);
		} else {
			sum = insertColumns(sum, lowA - lowSum);
			deltaX = 0;
		}

		Picture tmp = boundingBox(add(a, sum));

		if (areSame(tmp, b)) {

			int ansX = tmp.dx;
			int ansY = tmp.dy - deltaX;

			return new int[] { ansX, ansY };
		}
		
		return null;
	}

	Picture insertColumns(Picture a, int cols) {

		char[][] ret = new char[a.h][a.w + cols];
		for (int i = 0; i < ret.length; i++) {
			for (int j = 0; j < ret[0].length; j++) {

				if (j < cols) {
					ret[i][j] = '.';
				} else {
					ret[i][j] = a.f[i][j - cols];
				}

			}
		}

		return new Picture(a.h, a.w + cols, ret, a.dx, a.dy);
	}

	int[] go(Picture a, Picture b, Picture sum) {

		// a, b, sum = bounding boxes

		int[] ret = go2(a, b, sum);
		if (ret != null) {
			return ret;
		}

		ret = go2(b, a, sum);
		if (ret != null) {
			return new int[] { -ret[0], -ret[1] };
		}

		return null;
	}

	void solve() throws IOException {
		Picture one = nextPicture();
		Picture two = nextPicture();

		Picture sum = nextPicture();

		for (int i = 0; i < 4; i++) {
			int[] ret = go(one, two, sum);
			if (ret != null) {

				int ansX = ret[0];
				int ansY = ret[1];

				for (int j = 0; j < i; j++) {
					int newAnsX = ansY;
					int newAnsY = -ansX;

					ansX = newAnsX;
					ansY = newAnsY;
				}

				ansX += one.dx - two.dx;
				ansY += one.dy - two.dy;

				out.println("YES");
				out.println(ansY + " " + ansX);
				return;
			}

			one = rotate(one);
			two = rotate(two);
			sum = rotate(sum);

		}
		

//		Picture just = boundingBox(add(one, two));
		Picture just = add(one, two);
		if (areSame(just, sum)) {

			int ansX = one.dx - two.dx;
			int ansY = one.dy - two.dy;
			
			out.println("YES");
			out.println(ansY + " " + ansX);
			return;
		}
		
		out.println("NO");

	}

	Picture add(Picture a, Picture b) {

		char[][] ret = new char[Math.max(a.h, b.h)][Math.max(a.w, b.w)];
		for (int i = 0; i < ret.length; i++) {
			for (int j = 0; j < ret[0].length; j++) {

				char charA = (i < a.h && j < a.w ? a.f[i][j] : '.');
				char charB = (i < b.h && j < b.w ? b.f[i][j] : '.');

				if (charA == charB) {
					ret[i][j] = '.';
				} else {
					ret[i][j] = '*';
				}

			}
		}

		return new Picture(ret.length, ret[0].length, ret, 0, 0);
	}

	void run() {
		try {
			br = new BufferedReader(new FileReader("kids.in"));
			out = new PrintWriter("kids.out");
			solve();
			out.close();
		} catch (IOException e) {
			e.printStackTrace();
		}
	}

	String nextToken() throws IOException {
		while (st == null || !st.hasMoreTokens()) {
			st = new StringTokenizer(br.readLine());
		}
		return st.nextToken();
	}

	int nextInt() throws IOException {
		return Integer.parseInt(nextToken());
	}

	public static void main(String[] args) {
		new K().run();
	}
}
