#include <iostream>
#include <cstdio>
#include <cmath>
#include <algorithm>
#include <string>
#include <vector>
using namespace std;

typedef long long int int64;

struct Item
{
	int64 len, cnt;
	Item() : len(), cnt() {}
	Item(int64 _len, int64 _cnt) : len(_len), cnt(_cnt) {}

	bool operator == (const Item & other) const
	{
		return len == other.len && cnt == other.cnt;
	}
};

const int64 INF = (int64)1e18 + 1000;

int64 safe_add(int64 a, int64 b)
{
	return min(a + b, INF);
}

int64 safe_mul(int64 a, int64 b)
{
	if ((double)a * b > 2.0 * INF)
		return INF;
	return min(INF, a * b);
}

const int PRIMES_CNT = 1500;
const int PRIMES_SUM = 10000;

const Item empty_set = Item(4, 1);

int primes_cnt;
vector<int> primes;
Item dp[PRIMES_CNT + 1][PRIMES_SUM];

bool is_prime(int x)
{
	if (x < 2)
		return false;

	for (int i = 2; i * i <= x; i++)
		if (x % i == 0)
			return false;

	return true;
}

int get_len(int p)
{
	int l = 0;
	while (p > 0)
	{
		p /= 10;
		l++;
	}
	return l;
}

Item add_p(Item item, int p)
{
	if (item == empty_set)
		item.len = safe_add(item.len, get_len(p));
	else
		item.len = safe_add(item.len, safe_mul(item.cnt, get_len(p) + 2));
	return item;
}

Item add(Item a, Item b)
{
	if (a.len == 0)
		return b;
	if (b.len == 0)
		return a;

	if (a == empty_set && b == empty_set)
		return empty_set;

	return Item(safe_add(a.len, b.len), safe_add(a.cnt, b.cnt));
}

void init()
{
	for (int i = 0; i < PRIMES_SUM; i++)
		if (is_prime(i))
			primes.push_back(i);

	primes_cnt = (int)primes.size();

	if (primes_cnt > PRIMES_CNT)
	{
		cerr << "cnt" << endl;
		throw;
	}

	dp[primes_cnt][0] = empty_set;

	for (int p_id = primes_cnt - 1; p_id >= 0; p_id--)
	{
		int cur_p = primes[p_id];

		for (int sum = 0; sum < PRIMES_SUM; sum++)
		{
			Item cur_dp = dp[p_id + 1][sum];
			if (cur_p <= sum)
			{
				Item add_item = add_p(dp[p_id + 1][sum - cur_p], cur_p);
				cur_dp = add(cur_dp, add_item);
			}

			dp[p_id][sum] = cur_dp;
		}
	}

	int64 super_sum = 0;
	for (int i = 0; i < PRIMES_SUM; i++)
		super_sum = safe_add(super_sum, dp[0][i].len);

	if (super_sum != INF)
	{
		cerr << "!";
		throw;
	}
}

string to_str(int p)
{
	string res;
	while (p > 0)
	{
		res.push_back('0' + p % 10);
		p /= 10;
	}
	reverse(res.begin(), res.end());
	return res;
}

char get(int64 need_skip_len)
{
	//this is also index in 0-indexing

	int p_id = 0;
	int cur_sum = 2;

	while (need_skip_len >= dp[p_id][cur_sum].len)
	{
		need_skip_len -= dp[p_id][cur_sum].len;
		cur_sum++;
	}

	int pref_len = 0;
	string prefix = "[";
	
	while (true)
	{
		if (cur_sum == 0)
		{
			prefix += "], ";
			if (need_skip_len >= (int)prefix.length())
				throw;
			return prefix[need_skip_len];
		}

		int cur_p = primes[p_id];
		int cur_p_len = get_len(cur_p);
		
		if (cur_sum < cur_p)
			throw;

		int64 skip_len = 0;

		if (cur_sum == cur_p)
		{
			skip_len += pref_len + cur_p_len + 4;
		}
		else
		{
			skip_len = safe_mul(safe_add(pref_len, cur_p_len + 2), dp[p_id + 1][cur_sum - cur_p].cnt);
			skip_len = safe_add(skip_len, dp[p_id + 1][cur_sum - cur_p].len);
		}
		
		if (skip_len > need_skip_len)
		{
			if (prefix.length() != 1)
				prefix += ", ";
			prefix += to_str(cur_p);
			cur_sum -= cur_p;
			pref_len += cur_p_len + 2;
		}
		else
		{
			need_skip_len -= skip_len;
		}

		p_id++;
	}
}

int main()
{
#ifdef LOCAL
	freopen("input.txt", "r", stdin);
#else
	freopen("hard.in", "r", stdin);
	freopen("hard.out", "w", stdout);
#endif

	init();

	int64 a, b;
	cin >> a >> b;
	a--;
	b--;

	string res;

	for (int64 i = a; i <= b; i++)
		res.push_back(get(i));

	cout << res << endl;

	//cout << get(15) << endl;
	//return 0;

	//for (int i = 0; i < 200; i++)
		//cout << get(i);
		//cout << i << " " << get(i) << endl;

	return 0;
}