#define _CRT_SECURE_NO_WARNINGS
#include <iostream>
#include <cstdio>
#include <cstdlib>
#include <string>
#include <vector>
#include <cmath>
#include <set>
#include <vector>
#include <map>
#include <list>
using namespace std;

typedef long double ldb;
typedef ldb ld;
typedef long long llg;
typedef llg ll;

#define fori(i, n) for (int i = 0; i < (int)(n); i++)

const ldb eps = 1e-7;

bool eq(ldb a, ldb b) {
    return fabsl(a - b) < eps;
}

bool gr(ldb a, ldb b) {
    return a - eps > b;
}

bool ls(ldb a, ldb b) {
    return a + eps < b;
}

bool ls_eq(ldb a, ldb b) {
    return !gr(a, b);
}

bool gr_eq(ldb a, ldb b) {
    return !ls(a, b);
}


struct vect {
    ldb x, y;

    vect() : x(0), y(0) { }
    vect(ldb _x, ldb _y) : x(_x), y(_y) { }

    vect operator + (const vect &v) const {
        return vect(x + v.x, y + v.y);
    }

    vect operator - (const vect & v) const {
        return vect(x - v.x, y - v.y);
    }

    vect operator * (llg f) const {
        return vect(x * f, y * f);
    }

    vect operator / (llg f) const {
        return vect(x / f, y / f);
    }
};

struct plane {
    llg cnt;
    vect center;
    set<int> pos;
    int level, level_cnt;
    ldb w;

    plane() {
        level = INT_MAX;
    }
    plane(llg _cnt, vect _center, int cur_l, int pos_cnt, ldb _w) {
        w = _w;
        level_cnt = pos_cnt;
        fori(i, pos_cnt) {
            pos.insert(i + 1);
        }
        cnt = _cnt;
        center = _center;
        level = cur_l;
    }
    bool check() {
        
        if (cnt != 0 && pos.empty()) {
            return false;
        }
        else if (cnt == 0) {
            return true;
        }

        bool is_ok = true;

        vect rem_cnt = center / cnt;
        ldb to_cmp = (level % 2 == 1 ? rem_cnt.x : rem_cnt.y);

        if (gr_eq(to_cmp, *pos.rbegin() * w)) {
            is_ok = false;
        }
        else if (ls_eq(to_cmp, (*pos.begin() - 1) * w)) {
            is_ok = false;
        }
        return is_ok;
    }
};

list<plane> levels;

bool remove(int level, int num, ldb w, llg n) {
    
    vect cur_ch;
    if (level % 2 == 1) {
        cur_ch = vect(w / 2 + (num - 1) * w, n * w / 2);
    }
    else {
        cur_ch = vect(n * w / 2, w / 2 + (num - 1) * w);
    }

    bool is_ok = true;
    for (auto& pl : levels) {
        if (pl.level > level) {
            continue;
        }
        if (pl.level == level) {
            pl.pos.erase(num);
            is_ok &= pl.check();
        }
        else if (pl.level < level) {
            pl.center = pl.center - cur_ch;
            pl.cnt -= 1;
            is_ok &= pl.check();
        }
    }
    return is_ok;
}

#define taskname "jenga"
int main() {
#ifdef LOCAL
    freopen("input.txt", "r", stdin);
    freopen("output.txt", "w", stdout);
#else
    freopen(taskname".in", "r", stdin);
    freopen(taskname".out", "w", stdout);
#endif


    llg n, w;
    int h, m, l, k;
    cin >> n >> w >> h >> m;

    vect hor_x, hor_y;

    fori(i, n) {
        hor_x = hor_x + vect(w / 2.0 +  i * w, (ldb)n * w / 2.0);
        hor_y = hor_y + vect((ldb)n * w / 2.0, w / 2.0 + i * w);
    }


    vect last_cnt(0, 0);
    for (int i = h; i > 0; i--)
    {
        levels.push_back(plane(n * (h - i), last_cnt, i, n, w));
        last_cnt = last_cnt + (i % 2 == 1 ? hor_x : hor_y);
    }

    fori(i, m) {
        cin >> l >> k;
        if (!remove(l, k, w, n)) {
            cout << "yes" << endl << i + 1 << endl;
            return 0;
        }
    }

    cout << "no" << endl;

    return 0;
}