#include "bits/stdc++.h"

using namespace std;

using LL = long long;

namespace fractions {

	LL gcd(LL a, LL b) {
		while (b) {
			a %= b;
			swap(a, b);
		}
		return a;
	}

	struct frac {
		LL a, b;
		explicit frac() : a(0), b(1) {}
		explicit frac(LL x) : a(x), b(1) {}
		explicit frac(LL a, LL b) : a(a), b(b) { norm(); }

		void norm() {
			LL g = gcd(abs(a), abs(b));
			a /= g;
			b /= g;
			if (b < 0) a *= -1, b *= -1;
		}

		frac operator * (const frac& other) const {
			return frac(a * other.a, b * other.b);
		}
		frac operator / (const frac& other) const {
			return frac(a * other.b, b * other.a);
		}

		frac operator + (const frac& other) const {
			return frac(a * other.b + b * other.a, b * other.b);
		}
		frac operator - (const frac& other) const {
			return frac(a * other.b - b * other.a, b * other.b);
		}

		bool operator <= (const frac& other) const {
			return a * other.b <= b * other.a;
		}
		bool operator >= (const frac& other) const {
			return a * other.b >= b * other.a;
		}
	};

}  // namespace fractions


using LD = fractions::frac;

//const LD eps = 1e-9;
//
//int sign(LD x) {
//	if (x < eps) return -1;
//	if (x > eps) return +1;
//	return 0;
//}
//
//bool DLE(LD a, LD b) {
//	return sign(a - b) <= 0;
//}
//
//bool DGE(LD a, LD b) {
//	return sign(a - b) >= 0;
//}

struct vec {
	LD x, y;
	explicit vec() : x(0), y(0) {}
	explicit vec(LD x, LD y) : x(x), y(y) {}
	vec operator - (const vec& b) const {
		return vec(x - b.x, y - b.y);
	}
	vec operator + (const vec& b) const {
		return vec(x + b.x, y + b.y);
	}
	vec operator * (LD val) const {
		return vec(x * val, y * val);
	}
	vec operator / (LD val) const {
		return vec(x / val, y / val);
	}
};

const int N = 1e5 + 100;

int n, w, h, q;

int cnt[N];
vec center[N];
int mn[N], mx[N];
set<int> removed[N];
int maxNotBroke;

void init() {
	for (int i = 0; i < h; ++i) {
		center[i] = vec(LD(n, 2), LD(n, 2));
		cnt[i] = n;
		mn[i] = 0;
		mx[i] = n - 1;
	}
	maxNotBroke = h - 1;
}

void rem(int level, int idx) {
	cnt[level]--;
	removed[level].insert(idx);

	if (!cnt[level])
		return;

	if (mn[level] == idx) {
		mn[level]++;
		while (removed[level].count(mn[level])) {
			mn[level]++;
		}
	}

	if (mx[level] == idx) {
		mx[level]--;
		while (removed[level].count(mx[level])) {
			mx[level]--;
		}
	}

	if (level & 1) swap(center[level].x, center[level].y);

	center[level].x = (center[level].x * LD(cnt[level] + 1) - (LD(idx) + LD(1, 2))) / LD(cnt[level]);

	if (level & 1) swap(center[level].x, center[level].y);
}

bool check_collapse(int level, int elem) {
	rem(level, elem);
	if (cnt[level] == 0) {
		if (maxNotBroke != level)
			return true;
		else {
			while (maxNotBroke >= 0 && cnt[maxNotBroke] == 0)
				--maxNotBroke;
			return false;
		}
	}

	vec c(LD(0), LD(0));
	LL m = 0;
	for (int i = maxNotBroke; i >= 0; --i) {
		if (i != maxNotBroke) {
			vec cur = c / LD(m);
			if (i & 1) {
				swap(cur.x, cur.y);
			}
			const LD left = LD(mn[i]);
			const LD right = LD(mx[i] + 1);
			if (cur.x <= left || cur.x >= right) {
				return true;
			}
		}
		c = c + center[i] * LD(cnt[i]);
		m = m + cnt[i];
	}

	return false;
}

void solve() {
	cin >> n >> w >> h >> q;
	init();
	for (int i = 0; i < q; ++i) {
		int level, elem;
		cin >> level >> elem;
		if (check_collapse(level - 1, elem - 1)) {
			cout << "yes" << endl;
			cout << i + 1 << endl;
			return;
		}
	}
	cout << "no" << endl;
}

int main() {
#if ZEBER
	freopen("input.txt", "r", stdin);
#else
	freopen("jenga.in", "r", stdin);
	freopen("jenga.out", "w", stdout);
#endif
	ios_base::sync_with_stdio(false);
	cin.tie(0);
	solve();
}