#include <iostream>
#include <cassert>
#include <vector>
#include <algorithm>
#include <string> 
#include <iomanip>

using namespace std;

#define REP(i, n) for (int i = 0; i < n; ++i)
#define DB(x) cerr << #x << ": " << x << endl;

using LL = long long; 

struct Rect
{
  void read() {
    cin >> h >> w;
    resize(h, w);
    REP(i, h) {
      string s;
      cin >> s;
      REP(j, w) {
        field[i][j] = s[j] == '*';
      }
    }
  }

  void resize(int h_, int w_) {
    h = h_;
    w = w_;
    field.assign(h, vector<char>(w, 0));
  }

  int h, w;
  vector<vector<char>> field;
};

const int MAXH = 2010;
const int MAXW = 2010;

Rect computeXor(const Rect& r1, const Rect& r2, int sh1, int sw1, int sh2, int sw2) {
  Rect result;
  result.resize(MAXH * 2, MAXW * 2);
  REP(h, r1.h) {
    REP(w, r1.w) {
      result.field[MAXH - sh1 + h][MAXW - sw1 + w] ^= r1.field[h][w];
    }
  }
  REP(h, r2.h) {
    REP(w, r2.w) {
      result.field[MAXH - sh2 + h][MAXW - sw2 + w] ^= r2.field[h][w];
    }
  }
  return result;
}

LL mult = 7;
LL lineMult = 232717;
LL MOD = LL(1e9) * 1LL * LL(1e9) + 3LL;

bool isPrime(int x) {
  for (int i = 2; i * i <= x; ++i) {
    if (x % i == 0) {
      return false;
    }
  }
  return true;
}

LL rectHash(const Rect& r) {
  LL hash = 0;

  int minH = r.h;
  int minW = r.w;
  int maxH = 0;
  int maxW = 0;
  REP(h, r.h) {
    REP(w, r.w) {
      if (r.field[h][w]) {
        minH = min(minH, h);
        minW = min(minW, w);
        maxH = max(maxH, h);
        maxW = max(maxW, w);
      }
    }
  }
  for (int h = minH; h <= maxH; ++h) {
    for (int w = minW; w <= maxW; ++w) {
      hash *= mult;
      hash += r.field[h][w];
      hash %= MOD;
    }
    hash *= lineMult;
    hash %= MOD;
  }
  return hash;
}

pair<int, int> zero(-1, -1);

pair<int, int> findTopLeft(const Rect& r) {
  REP(h, r.h) {
    REP(w, r.w) {
      if (r.field[h][w] == 1) {
        return make_pair(h, w);
      }
    }
  }
  return zero;
}

int minExcl(const vector<int>& v) {
  REP(i, 3) {
    if (find(v.begin(), v.end(), i) == v.end()) {
      return i;
    }
  }
  return -1;
}

void printRect(const Rect& r1) {
  int minH = r1.h;
  int minW = r1.w;
  int maxH = 0;
  int maxW = 0;
  REP(h, r1.h) {
    REP(w, r1.w) {
      if (r1.field[h][w]) {
        minH = min(minH, h);
        minW = min(minW, w);
        maxH = max(maxH, h);
        maxW = max(maxW, w);
      }
    }
  }
  for (int h = minH; h <= maxH; ++h) {
    for (int w = minW; w <= maxW; ++w) {
      cerr << (r1.field[h][w] ? 1 : 0);
    }
    cerr << endl;
  }
  cerr << endl;
}

int main() {
  while (!isPrime(lineMult)) {
    ++lineMult;
  }

  freopen("kids.in", "r", stdin); 
  freopen("kids.out", "w", stdout); 

  Rect rects[3];
  pair<int, int> pairs[3];
  LL hashes[3];
  REP(i, 3) {
    rects[i].read();
    pairs[i] = findTopLeft(rects[i]);
    hashes[i] = rectHash(rects[i]);
    //printRect(rects[i]);
    //DB(hashes[i]);
  }

  for (int i = 0; i < 3; ++i) {
    const auto& ri = rects[i];
    auto pi = pairs[i];
    for (int j = i + 1; j < 3; ++j) {
      const auto& rj = rects[j];
      auto pj = pairs[j];
      int k = minExcl(vector<int>{i, j});
      const auto& hk = hashes[k];
      assert(k != -1);

      if (pi == zero || pj == zero) {
        continue;
      }

      auto rXor = computeXor(ri, rj, pi.first, pi.second, pj.first, pj.second);
      auto xorHash = rectHash(rXor);
      /*
      printRect(rXor);
      DB(xorHash);
      DB(hk);
      */
      if (xorHash == hk) {
        //cerr << "match: " << i << " " << j << endl;
        cout << "YES" << endl;
        auto pxor = findTopLeft(rXor);
        pxor.first -= MAXH;
        pxor.second -= MAXW;
        swap(pi.first, pi.second);
        swap(pj.first, pj.second);
        swap(pxor.first, pxor.second);

        /*
        cerr << pi.first << " " << pi.second << endl;
        cerr << pj.first << " " << pj.second << endl;
        cerr << pxor.first << " " << pxor.second << endl;
        */
        

        if (i == 0 && j == 1) {
          cout << pi.first - pj.first << " " 
               << pi.second - pj.second << endl;
        } else {
          if (i == 0 && j == 2) {
            cout << pxor.first + pi.first << " " 
                 << pxor.second + pi.second << endl;
          }
          if (i == 1 && j == 2) {
            cout << -pxor.first - pi.first << " " 
                 << -pxor.second - pi.second << endl;
          }
        }

        return 0;
      }
    }
  }
  cout << "NO" << endl;
	return 0;
}
