#pragma region header
#include <iostream>
#include <algorithm>
#include <vector>
#include <string>
#include <set>
#include <map>
#include <queue>
#include <bitset>
#include <complex>
#include <random>
#include <cmath>
#include <ctime>
#include <cstring>
using namespace std;

#pragma comment(linker, "/STACK:16000000")
typedef long long ll;
typedef pair<int, int> pii;

#ifdef LOCAL
#define eprintf(...) fprintf(stderr, __VA_ARGS__)
#else
#define eprintf(...) (void)0
#endif
#pragma endregion

const int H = 5005;
const int N = 10500;

struct Point
{
	ll x, y;
	Point() : x(), y() {}
	Point(ll _x, ll _y) : x(_x), y(_y) {}
	Point operator+(const Point &p) const
	{
		return Point(x + p.x, y + p.y);
	}
	Point operator-(const Point &p) const
	{
		return Point(x - p.x, y - p.y);
	}
};

int n, w, h, m;
bool taken[H][N];
int lvl_cnt[H];
Point lvl_sum[H];
int lptr[H], rptr[H];

Point get_center(int l, int k)
{
	if (l % 2 == 0)
		return Point(2 * k * w - w, n * w);
	return Point(n * w, 2 * k * w - w);
}

void remove_block(int l, int k)
{
	taken[l][k] = true;
	lvl_cnt[l]--;
	lvl_sum[l] = lvl_sum[l] - get_center(l, k);
	while (lptr[l] < n && taken[l][lptr[l]])
		lptr[l]++;
	while (rptr[l] >= 0 && taken[l][rptr[l]])
		rptr[l]--;
}

bool is_falling()
{
	while (h > 0 && lvl_cnt[h - 1] == 0)
		h--;
	Point sum;
	int cnt = 0;
	for (int i = h - 1; i >= 0; i--)
	{
		if (lvl_cnt[i] == 0)
			return true;
		if (i < h - 1)
		{
			if (i % 2 == 0)
			{
				ll left_x = get_center(i, lptr[i]).x - w;
				ll right_x = get_center(i, rptr[i]).x + w;
				if (!(left_x * cnt < sum.x && sum.x < right_x * cnt))
					return true;
			}
			else
			{
				ll left_y = get_center(i, lptr[i]).y - w;
				ll right_y = get_center(i, rptr[i]).y + w;
				if (!(left_y * cnt < sum.y && sum.y < right_y * cnt))
					return true;
			}
		}
		sum = sum + lvl_sum[i];
		cnt += lvl_cnt[i];
	}
	return false;
}

void solve()
{
	scanf("%d%d%d%d", &n, &w, &h, &m);

	for (int i = 0; i < h; i++)
	{
		lptr[i] = 0;
		rptr[i] = n - 1;
		lvl_cnt[i] = n;
		if (i <= 1)
		{
			for (int j = 0; j < n; j++)
				lvl_sum[i] = lvl_sum[i] + get_center(i, j);
		}
		else
			lvl_sum[i] = lvl_sum[i - 2];
	}

	for (int i = 0; i < m; i++)
	{
		int l, k;
		scanf("%d%d", &l, &k);
		l--; k--;
		remove_block(l, k);
		if (is_falling())
		{
			printf("yes\n%d\n", i + 1);
			return;
		}
	}

	puts("no");
}

void main()
{
#ifdef LOCAL
	freopen("input.txt", "r", stdin);
	//freopen("output.txt", "w", stdout);
#else
	freopen("jenga.in", "r", stdin);
	freopen("jenga.out", "w", stdout);
#endif

	solve();

	eprintf("\n\ntime: %.3lf\n", (double)clock() / CLOCKS_PER_SEC);
}